summaryrefslogtreecommitdiff
path: root/configs/example
diff options
context:
space:
mode:
Diffstat (limited to 'configs/example')
-rw-r--r--configs/example/memtest-ruby.py24
-rw-r--r--configs/example/ruby_direct_test.py (renamed from configs/example/determ_test.py)6
-rw-r--r--configs/example/rubytest.py2
3 files changed, 18 insertions, 14 deletions
diff --git a/configs/example/memtest-ruby.py b/configs/example/memtest-ruby.py
index d2e9c137e..e32e0c114 100644
--- a/configs/example/memtest-ruby.py
+++ b/configs/example/memtest-ruby.py
@@ -104,17 +104,21 @@ system = System(cpu = cpus,
funcmem = PhysicalMemory(),
physmem = PhysicalMemory())
-system.dmas = [ MemTest(atomic = False, \
- max_loads = options.maxloads, \
- issue_dmas = True, \
- percent_functional = 0, \
- percent_uncacheable = 0, \
- progress_interval = options.progress) \
- for i in xrange(options.num_dmas) ]
+if options.num_dmas > 0:
+ dmas = [ MemTest(atomic = False, \
+ max_loads = options.maxloads, \
+ issue_dmas = True, \
+ percent_functional = 0, \
+ percent_uncacheable = 0, \
+ progress_interval = options.progress) \
+ for i in xrange(options.num_dmas) ]
+ system.dma_devices = dmas
+else:
+ dmas = []
system.ruby = Ruby.create_system(options, \
- system.physmem, \
- dma_devices = system.dmas)
+ system, \
+ dma_devices = dmas)
#
# The tester is most effective when randomization is turned on and
@@ -131,7 +135,7 @@ for (i, cpu) in enumerate(cpus):
cpu.test = system.ruby.cpu_ruby_ports[i].port
cpu.functional = system.funcmem.port
-for (i, dma) in enumerate(system.dmas):
+for (i, dma) in enumerate(dmas):
#
# Tie the dma memtester ports to the correct functional port
# Note that the test port has already been connected to the dma_sequencer
diff --git a/configs/example/rubytest.py b/configs/example/rubytest.py
index a4daf6b82..ddd6a53af 100644
--- a/configs/example/rubytest.py
+++ b/configs/example/rubytest.py
@@ -90,7 +90,7 @@ tester = RubyTester(checks_to_complete = options.checks,
# actually used by the rubytester, but is included to support the
# M5 memory size == Ruby memory size checks
#
-system = System(physmem = PhysicalMemory())
+system = System(tester = tester, physmem = PhysicalMemory())
system.ruby = Ruby.create_system(options, system)
diff --git a/configs/example/determ_test.py b/configs/example/ruby_direct_test.py
index 77712ffd9..e744c35bd 100644
--- a/configs/example/determ_test.py
+++ b/configs/example/ruby_direct_test.py
@@ -69,7 +69,7 @@ if args:
sys.exit(1)
#
# Select the directed generator
#
if options.test_type == "SeriesGetx":
generator = SeriesRequestGenerator(num_cpus = options.num_cpus,
@@ -80,7 +80,7 @@ elif options.test_type == "SeriesGets":
elif options.test_type == "Invalidate":
generator = InvalidateGenerator(num_cpus = options.num_cpus)
else:
- print "Error: unknown directed generator"
+ print "Error: unknown direct test generator"
sys.exit(1)
#
@@ -95,7 +95,7 @@ system = System(physmem = PhysicalMemory())
#
system.tester = RubyDirectedTester(requests_to_complete = \
options.requests,
- generator = generator)
+ generator = generator)
system.ruby = Ruby.create_system(options, system)
@@ -69,7 +69,7 @@ if args:
sys.exit(1)
#
-# Select the directed generator
+# Select the direct test generator
#
if options.test_type == "SeriesGetx":